#include <bits/stdc++.h>
#define endl '\n'

using namespace std;
template<class T, class T1> void chkmin(T &x, const T1 &y) { if(x > y) x = y; }
template<class T, class T1> void chkmax(T &x, const T1 &y) { if(x < y) x = y; }
const int MAXN = (1 << 20);
const int inf = (int)1e9 + 17;

template<class FlowT>
struct max_flow
{
    const static FlowT finf = 1e9 + 42 + 17;
    const static FlowT feps = 0;

    struct edge
    {
        FlowT flow, cap;
        int rev, to;
        edge()
        {
            flow = 0;
            cap = 0;
            rev = 0;
            to = 0;
        }
        edge(int _to, int _rev, FlowT _flow, FlowT _cap)
        {
            to = _to;
            rev = _rev;
            flow = _flow;
            cap = _cap;
        }
    };

    vector<edge> G[MAXN];
    int n, dist[MAXN], po[MAXN];

    bool bfs(int s, int t)
    {
        dist[s] = -1, po[s] = 0;
        dist[t] = -1, po[t] = 0;
        for(int v = 0; v <= n; v++)
            dist[v] = -1, po[v] = 0;

        queue<int> Q;
        Q.push(s);
        dist[s] = 0;

        while(!Q.empty())
        {
            int u = Q.front();
            Q.pop();

            for(edge e: G[u])
                if(dist[e.to] == -1 && e.flow < e.cap)
                {
                    dist[e.to] = dist[u] + 1;
                    Q.push(e.to);
                }
        }

        return dist[t] != -1;
    }

    FlowT dfs(int u, int t, FlowT fl = finf)
    {
        if(u == t)
            return fl;

        for(; po[u] < G[u].size(); po[u]++)
        {
            auto &e = G[u][po[u]];
            if(dist[e.to] == dist[u] + 1 && e.flow < e.cap)
            {
                FlowT f = dfs(e.to, t, min(fl, e.cap - e.flow));

                e.flow += f;
                G[e.to][e.rev].flow -= f;

                if(f > 0)
                    return f;
            }
        }

        return 0;
    }

    void init(int _n)
    {
        n = _n;
        for(int i = 0; i <= n; i++)
            G[i].clear();
    }

    void add_edge(int u, int v, FlowT w)
    {
        G[u].push_back(edge(v, G[v].size(), 0, w));
        G[v].push_back(edge(u, G[u].size() - 1, 0, 0));
    }

    FlowT flow(int s, int t)
    {
        if(s == t)
            return finf;

        FlowT ret = 0, to_add;
        while(bfs(s, t))
            while((to_add = dfs(s, t)))
                ret += to_add;

        return ret;
    }
};

int n, p, b, d;
int a[MAXN];

void read()
{
    cin >> p >> n >> d >> b;
    for(int i = 0; i < n; i++)
        cin >> a[i];
}

max_flow<int> mf;
int CNT;

void init(int l, int r, int idx)
{
    if(idx != 0) mf.add_edge((idx - 1) >> 1, idx, inf);
    if(l == r)
    {
        mf.add_edge(idx, CNT + n + 3, b);
        return;
    }

    int mid = (l + r) >> 1;
    init(l, mid, 2 * idx + 1);
    init(mid + 1, r, 2 * idx + 2);
}

void pre_init(int l, int r, int idx)
{
    chkmax(CNT, idx + 1);
    if(l == r) return;

    int mid = (l + r) >> 1;
    pre_init(l, mid, 2 * idx + 1);
    pre_init(mid + 1, r, 2 * idx + 2);
}

void add_edges_to_mf(int ql, int qr, int l, int r, int idx, int from)
{
    if(ql > qr || l > r || ql > r || qr < l) return;
    if(ql <= l && r <= qr)
    {
        mf.add_edge(from, idx, inf);
        return;
    }

    int mid = (l + r) >> 1;
    add_edges_to_mf(ql, qr, l, mid, 2 * idx + 1, from);
    add_edges_to_mf(ql, qr, mid + 1, r, 2 * idx + 2, from);
}

int dist(int a, int b)
{
    int len = max(a - b, b - a);
    return len / d + (len % d != 0);
}

int destr(int x)
{
    int ret2 = dist(n, x);
    int ret = dist(-1, x);
    if(p == 1) return ret;
    return min(ret, ret2);
}

bool check(int l)
{
    int s = CNT + n + 2, t = CNT + n + 3;
    mf.init(t + 2);

    int L = l, R = n - 1;
    if(p == 2) R = n - l - 1;

    init(L, R, 0);

    int c_l = 0, c_r = 0;
    while(c_r < R && dist(0, c_r + 1) <= destr(c_r + 1)) c_r++;
    while(c_l <= R && dist(0, c_l) > destr(c_l)) c_l++;

    for(int i = 0; i < n; i++)
    {
        while(c_r < R && dist(i, c_r + 1) <= destr(c_r + 1)) c_r++;
        while(c_l <= R && dist(i, c_l) > destr(c_l)) c_l++;

        mf.add_edge(s, CNT + i, a[i]);
        add_edges_to_mf(c_l, c_r, L, R, 0, CNT + i);
        //cout << i << " -> " << c_l << " " << c_r << endl;
    }

    int C = mf.flow(s, t);

    return C == b * (R - L + 1);
}

void solve()
{
    pre_init(0, n - 1, 0);

    int low = 0, high = n / 2, mid, ret = n / 2 + 1;
    while(low <= high)
    {
        mid = (low + high) >> 1;
        if(check(mid))
            high = mid - 1, ret = mid;
        else
            low = mid + 1;
    }

    cout << ret << endl;
}

int main()
{
    ios_base::sync_with_stdio(false);
    cin.tie(NULL);

    read();
    solve();
    return 0;
}

/*
2 5 1 1
1 0 0 0 4
*/
