#include <bits/stdc++.h>
#define endl '\n'
using namespace std;

const int MAX_N = 1e5 + 5;

class Dag {
public:
	class Node {
	public:
		int id, componentSize;
		vector< Node* > v;
	};

	int cntNodes;
	Node nodes[MAX_N];

	void Init(int cntNodes) {
		this->cntNodes = cntNodes;

		for(int i = 1; i <= cntNodes; i++) {
			nodes[i].id = i;
		}
	}
};

class Graph {
public:
	class Node {
	public:
		bool isVisited;
		int id, indOfScc;
		vector< Node* > v, revV;
	};

	int cntNodes;
	Node nodes[MAX_N];
	
	void Init(int cntNodes) {
		this->cntNodes = cntNodes;

		for(int i = 1; i <= cntNodes; i++) {
			nodes[i].isVisited = false;
			nodes[i].id = i;
		}
	}

	void MarkNodesAsUnvisited() {
		for(int i = 1; i <= cntNodes; i++) {
			nodes[i].isVisited = false;
		}
	}

	void Dfs(Node *nd, stack< Node* > &st) {
		nd->isVisited = true;

		for(Node *x : nd->v) {
			if(!x->isVisited) {
				Dfs(x, st);
			}
		}
		
		st.push(nd);
	}

	void DfsRev(Node *nd, int sccInd) {
		nd->isVisited = true;
		nd->indOfScc = sccInd;

		for(Node *x : nd->revV) {
			if(!x->isVisited) {
				DfsRev(x, sccInd);	
			}
		}
	}

	void BuildDag(Dag &dag) {
		stack< Node* > st;

		for(int i = 1; i <= cntNodes; i++) {
			if(!nodes[i].isVisited) {
				Dfs(&nodes[i], st);
			}
		}

		MarkNodesAsUnvisited();

		int sccInd = 1;
		while(!st.empty()) {
			Node *curr = st.top();
			st.pop();

			if(!curr->isVisited) {
				DfsRev(curr, sccInd);
				sccInd++;
			}
		}

		dag.Init(sccInd - 1);
	
		for(int i = 1; i <= cntNodes; i++) {
			dag.nodes[nodes[i].indOfScc].componentSize++;
			for(Node *x : nodes[i].v) {
				if(x->indOfScc != nodes[i].indOfScc) {
					dag.nodes[nodes[i].indOfScc].v.push_back(&dag.nodes[x->indOfScc]);
				}
			}
		}
	}
};

int maintenanceTimes[MAX_N];
Graph initGraph;
Dag dag;

int main() {
	ios_base::sync_with_stdio(false);
	cin.tie(nullptr);

	int n, m, h;
	cin >> n >> m >> h;

	for(int i = 1; i <= n; i++) {
		cin >> maintenanceTimes[i];
	}

	initGraph.Init(n);
	for(int i = 0; i < m; i++) {
		int x, y;
		cin >> x >> y;

		int newTimeOfX = (maintenanceTimes[x] + 1) % h;
		int newTimeOfY = (maintenanceTimes[y] + 1) % h;

		if(newTimeOfY == maintenanceTimes[x]) {
			initGraph.nodes[y].v.push_back(&initGraph.nodes[x]);
			initGraph.nodes[x].revV.push_back(&initGraph.nodes[y]);
		}
		else if(newTimeOfX == maintenanceTimes[y]) {
			initGraph.nodes[x].v.push_back(&initGraph.nodes[y]);
			initGraph.nodes[y].revV.push_back(&initGraph.nodes[x]);
		}
	}

	initGraph.BuildDag(dag);

	int ans = -1, ansInd = -1;
	for(int i = 1; i <= dag.cntNodes; i++) {
		if(dag.nodes[i].v.size() == 0) {
			if(ans == -1 || ans > dag.nodes[i].componentSize) {
				ans = dag.nodes[i].componentSize;
				ansInd = i;
			}
		}
	}

	cout << ans << endl;

	for(int i = 1; i <= initGraph.cntNodes; i++) {
		if(initGraph.nodes[i].indOfScc == ansInd) {
			cout << i << " ";
		}
	}
	cout << endl;

	return 0;
}
