#define _CRT_SECURE_NO_WARNINGS
#include <iostream>
#include <vector>
#include <map>
#include <string>
#include <set>
#include <algorithm>
#include <cmath>
#include <complex>
using namespace std;

void fourier(vector < complex < double > > &v, long long mn = 2) {
	while (v.size() <= mn || (v.size() & (v.size() - 1)) != 0)
		v.push_back(0);
	long long len = v.size();
	long long k = log2(len);
	vector < long long > d(len);
	for (long long i = 0; i < len; i++)
		d[i] = ((d[i >> 1] >> 1) | ((i & 1) << k - 1));
	for (long long i = 0; i < len; i++)
		if (i < d[i])
			swap(v[i], v[d[i]]);
	for (long long l = 1; l < len; l *= 2) {
		complex < double > wd(cos(acos(-1) / l), sin(acos(-1) / l));
		for (long long i = 0; i < len; i += 2 * l) {
			complex < double > w(1, 0);
			for (long long j = 0; j < l; j++) {
				auto v1 = v[i + j];
				auto v2 = v[i + j + l];
				v[i + j] = v1 + v2 * w;
				v[i + j + l] = v1 - v2 * w;
				w *= wd;
			}
		}
	}
}

long long rnd() {
	return (rand() << 16) | rand();
}

long long rnd(long long l, long long r) {
	return l + rnd() % (r - l + 1);
}

struct node {
	node *l, *r;
	long long x, y;
	long long cnt;

	node() {
		l = r = NULL;
		x = 0;
		y = rnd();
		cnt = 1;
	}
	node(long long data) {
		l = r = NULL;
		x = data;
		y = rnd();
		cnt = 1;
	}
};

long long sz(node *v) {
	return !v ? 0 : v->cnt;
}

node * rec(node *v) {
	if (!v)
		return v;
	v->cnt = sz(v->l) + sz(v->r) + 1;
	return v;
}

node *merge(node *l, node *r) {
	if (!l || !r)
		return !l ? r : l;
	if (l->y > r->y) {
		l->r = merge(l->r, r);
		return rec(l);
	}
	r->l = merge(l, r->l);
	return rec(r);
}

pair < node*, node* > split(node *v, long long cnt) {
	if (!v)
		return{ NULL, NULL };
	if (sz(v->l) >= cnt) {
		auto p = split(v->l, cnt);
		v->l = p.second;
		return { p.first, rec(v) };
	}
	auto p = split(v->r, cnt - 1 - sz(v->l));
	v->r = p.first;
	return { rec(v), p.second };
}

void print(node *v) {
	if (!v)
		return;
	print(v->l);
	cout << v->x << ' ';
	print(v->r);
}

void println(node *v) {
#ifdef _DEBUG
	print(v);
	cout << endl;
#endif
}

void add(node *&root, long long value) {
	root = merge(root, new node(value));
}

const long long aholen = 1e2;
const long long alp = 26;
long long link[aholen][alp], go[aholen][alp], suf[aholen], suff[aholen], sym[aholen], ter[aholen], par[aholen];
long long root = 0;
long long tp = 0;

long long create() {
	for (long long i = 0; i < alp; i++)
		link[tp][i] = go[tp][i] = -1;
	suf[tp] = -1;
	suff[tp] = -1;
	sym[tp] = -1;
	ter[tp] = 0;
	return tp++;
}

void add(string &s) {
	long long pos = root;
	for (long long i = 0; i < s.size(); i++) {
		long long sm = s[i] - 'a';
		if (link[pos][sm] == -1) {
			long long f = create();
			link[pos][sm] = f;
			sym[f] = sm;
			par[f] = pos;
		}
		pos = link[pos][sm];
	}
	ter[pos]++;
}

long long gsuf(long long v);

long long ggo(long long v, long long s) {
	if (go[v][s] != -1)
		return go[v][s];
	if (link[v][s] != -1)
		return go[v][s] = link[v][s];
	if (v == root)
		return go[v][s] = root;
	return go[v][s] = ggo(gsuf(v), s);
}

long long gsuf(long long v) {
	if (suf[v] != -1)
		return suf[v];
	if (v == root || par[v] == root)
		return suf[v] = root;
	return suf[v] = ggo(gsuf(par[v]), sym[v]);
}

long long gsuff(long long v) {
	if (suff[v] != -1)
		return suff[v];
	if (v == root || par[v] == root)
		return suff[v] = root;
	if (ter[gsuf(v)] != 0)
		return suff[v] = gsuf(v);
	return suff[v] = gsuff(gsuf(v));
}

const long long len = 2e5;
long long p, n, d, b;
long long x[len];

long long ins(long long from, long long to, long long value) {
	return from <= value && value <= to;
}

bool win[len];

int main() {
#ifdef _DEBUG
	freopen("input.txt", "r", stdin);
	freopen("output.txt", "w", stdout);
#endif
	cin >> p >> n >> d >> b;
	for (long long i = 0; i < n; i++)
		cin >> x[i];
	if (p == 1) {
		long long ans = 0;

		long long pos = 0;
		long long step = 1;
		while (pos < n) {
			long long add = 0;
			for (long long i = pos + 1; i < n; i++) {
				if (i - d * step <= pos)
					add += x[i];
			}
			if (x[pos] > b) {
				x[pos + 1] += x[pos] - b;
			}
			else if (add + x[pos] < b) {
				x[pos + 1] += x[pos];
				ans++;
			}
			else {
				long long need = b - x[pos];
				for (long long i = n; i > pos; i--) {
					if (i - d * step <= pos) {
						long long f = min(x[i], need);
						x[i] -= f;
						need -= f;
					}
				}
			}
			step++;
			pos++;
		}

		cout << ans;
	}
	else {
		long long x1, x2;
		x1 = x2 = 0;
		long long l = 0, r = n - 1;
		long long step = 1;
		while (l < r) {
			long long needl = max(0ll, b - x[l]);
			long long needr = max(0ll, b - x[r]);

			long long gl = 0, gr = 0, both = 0;
			win[l] = win[r] = true;
			for (long long i = 0; i < n; i++) {
				if ((!win[i] || x[i] > b)) {
					if (ins(i - step * d, i + step * d, l) && ins(i - step * d, i + step * d, r))
						both += !win[i] ? x[i] : x[i] - b;
					else if (ins(i - step * d, i + step * d, l))
						gl += !win[i] ? x[i] : x[i] - b;
					else if (ins(i - step * d, i + step * d, r))
						gr += !win[i] ? x[i] : x[i] - b;
				}
			}

			if (needl - min(needl, gl) + needr - min(needr, gr) <= both) {
				for (long long i = n - 1; i >= 0; i--) {
					if ((!win[i] || x[i] > b)) {
						if (ins(i - step * d, i + step * d, l) && ins(i - step * d, i + step * d, r)) {
							// PASS
						}
						else if (ins(i - step * d, i + step * d, l)) {
							long long f = min(!win[i] ? x[i] : x[i] - b, needl);
							x[l] += f;
							x[i] -= f;
							needl -= f;
						}
						else if (ins(i - step * d, i + step * d, r)) {
							long long f = min(!win[i] ? x[i] : x[i] - b, needr);
							x[r] += f;
							x[i] -= f;
							needr -= f;
						}
					}
				}
				for (long long i = n - 1; i >= 0; i--) {
					if ((!win[i] || x[i] > b)) {
						if (ins(i - step * d, i + step * d, l) && ins(i - step * d, i + step * d, r)) {
							long long f = min(!win[i] ? x[i] : x[i] - b, needl);
							x[l] += f;
							x[i] -= f;
							needl -= f;

							f = min(!win[i] ? x[i] : x[i] - b, needr);
							x[r] += f;
							x[i] -= f;
							needr -= f;
						}
					}
				}
			}
			else {
				win[l] = win[r] = false;
				x1++;
				x2++;
			}

			step++;
			l++;
			r--;
		}

		cout << max(x1, x2);
	}
}