#define _CRT_SECURE_NO_WARNINGS
#include <iostream>
#include <vector>
#include <map>
#include <string>
#include <set>
#include <algorithm>
#include <cmath>
#include <ctime>
#include <complex>
using namespace std;

void fourier(vector < complex < double > > &v, int mn = 2) {
	while (v.size() <= mn || (v.size() & (v.size() - 1)) != 0)
		v.push_back(0);
	int len = v.size();
	int k = log2(len);
	vector < int > d(len);
	for (int i = 0; i < len; i++)
		d[i] = ((d[i >> 1] >> 1) | ((i & 1) << k - 1));
	for (int i = 0; i < len; i++)
		if (i < d[i])
			swap(v[i], v[d[i]]);
	for (int l = 1; l < len; l *= 2) {
		complex < double > wd(cos(acos(-1) / l), sin(acos(-1) / l));
		for (int i = 0; i < len; i += 2 * l) {
			complex < double > w(1, 0);
			for (int j = 0; j < l; j++) {
				auto v1 = v[i + j];
				auto v2 = v[i + j + l];
				v[i + j] = v1 + v2 * w;
				v[i + j + l] = v1 - v2 * w;
				w *= wd;
			}
		}
	}
}

int rnd() {
	return (rand() << 16) | rand();
}

int rnd(int l, int r) {
	return l + rnd() % (r - l + 1);
}

struct node {
	node *l, *r;
	int x, y;
	int cnt;

	node() {
		l = r = NULL;
		x = 0;
		y = rnd();
		cnt = 1;
	}
	node(int data) {
		l = r = NULL;
		x = data;
		y = rnd();
		cnt = 1;
	}
};

int sz(node *v) {
	return !v ? 0 : v->cnt;
}

node * rec(node *v) {
	if (!v)
		return v;
	v->cnt = sz(v->l) + sz(v->r) + 1;
	return v;
}

node *merge(node *l, node *r) {
	if (!l || !r)
		return !l ? r : l;
	if (l->y > r->y) {
		l->r = merge(l->r, r);
		return rec(l);
	}
	r->l = merge(l, r->l);
	return rec(r);
}

pair < node*, node* > split(node *v, int cnt) {
	if (!v)
		return{ NULL, NULL };
	if (sz(v->l) >= cnt) {
		auto p = split(v->l, cnt);
		v->l = p.second;
		return { p.first, rec(v) };
	}
	auto p = split(v->r, cnt - 1 - sz(v->l));
	v->r = p.first;
	return { rec(v), p.second };
}

void print(node *v) {
	if (!v)
		return;
	print(v->l);
	cout << v->x << ' ';
	print(v->r);
}

void println(node *v) {
#ifdef _DEBUG
	print(v);
	cout << endl;
#endif
}

void add(node *&root, int value) {
	root = merge(root, new node(value));
}

const int aholen = 1e2;
const int alp = 26;
int link[aholen][alp], go[aholen][alp], suf[aholen], suff[aholen], sym[aholen], ter[aholen], par[aholen];
int root = 0;
int tp = 0;

int create() {
	for (int i = 0; i < alp; i++)
		link[tp][i] = go[tp][i] = -1;
	suf[tp] = -1;
	suff[tp] = -1;
	sym[tp] = -1;
	ter[tp] = 0;
	return tp++;
}

void add(string &s) {
	int pos = root;
	for (int i = 0; i < s.size(); i++) {
		int sm = s[i] - 'a';
		if (link[pos][sm] == -1) {
			int f = create();
			link[pos][sm] = f;
			sym[f] = sm;
			par[f] = pos;
		}
		pos = link[pos][sm];
	}
	ter[pos]++;
}

int gsuf(int v);

int ggo(int v, int s) {
	if (go[v][s] != -1)
		return go[v][s];
	if (link[v][s] != -1)
		return go[v][s] = link[v][s];
	if (v == root)
		return go[v][s] = root;
	return go[v][s] = ggo(gsuf(v), s);
}

int gsuf(int v) {
	if (suf[v] != -1)
		return suf[v];
	if (v == root || par[v] == root)
		return suf[v] = root;
	return suf[v] = ggo(gsuf(par[v]), sym[v]);
}

int gsuff(int v) {
	if (suff[v] != -1)
		return suff[v];
	if (v == root || par[v] == root)
		return suff[v] = root;
	if (ter[gsuf(v)] != 0)
		return suff[v] = gsuf(v);
	return suff[v] = gsuff(gsuf(v));
}

const int len = 20000;
const int shift = 3000;
bool can[len];

int main() {
#ifdef _DEBUG
	freopen("input.txt", "r", stdin);
	freopen("output.txt", "w", stdout);
#endif
	int x;
	cin >> x;
	vector < int > a(x);
	for (int i = 0; i < x; i++)
		cin >> a[i];
	int cnt = 9;
	vector < int > ans;
	bool emp = true;

	int range = 600;

	for (int mask = 0; mask < 1 << cnt; mask++) {
		int kek = mask;
		while (kek >= 0) {
			vector < int > now;

			for (int j = 0; j < cnt; j++) {
				if ((mask & (1 << j)) != 0) {
					if ((kek & (1 << j)) != 0)
						now.push_back(1 << j);
					else
						now.push_back(-1 << j);
				}
			}

			/*set < int > f;
			f.insert(0);
			for (auto add : now) {
				set < int > next;
				for (auto el : f)
					next.insert(el + add);
				for (auto el : f)
					next.insert(el);
				f = next;
			}*/

			for(int i = -range;i <= range;i++)
				can[shift + i] = false;

			can[shift] = true;
			for(auto el: now){
				if(el > 0){
					for(int j = range;j >= -range;j--)
						if(can[shift + j])
							can[shift + j + el] = true;
				} else {
					for(int j = -range;j <= range;j++)
						if(can[shift + j])
							can[shift + j + el] = true;
				}
			}

			bool ok = true;
			for (auto el : a)
				if (!can[shift + el])
					ok = false;
			if (ok) {
				if (emp || ans.size() >= now.size())
					ans = now, emp = false;
			}

			if (kek == 0)
				break;
			kek = (kek - 1) & mask;
		}
	}
	cout << ans.size() << endl;
	for (auto el : ans)
		cout << el << ' ';
	cerr << clock() << endl;
}