#define _CRT_SECURE_NO_WARNINGS
#include <iostream>
#include <vector>
#include <map>
#include <string>
#include <set>
#include <algorithm>
#include <cmath>
#include <complex>
using namespace std;

void fourier(vector < complex < double > > &v, int mn = 2) {
    while (v.size() <= mn || (v.size() & (v.size() - 1)) != 0)
        v.push_back(0);
    int len = v.size();
    int k = log2(len);
	vector < int > d(len);
    for (int i = 0; i < len; i++) 
        d[i] = ((d[i >> 1] >> 1) | ((i & 1) << k - 1));
    for (int i = 0; i < len; i++)
        if (i < d[i])
            swap(v[i], v[d[i]]);
    for (int l = 1; l < len; l *= 2) {
        complex < double > wd(cos(acos(-1) / l), sin(acos(-1) / l));
        for (int i = 0; i < len; i += 2 * l) {
            complex < double > w(1, 0);
            for (int j = 0; j < l; j++) {
                auto v1 = v[i + j];
                auto v2 = v[i + j + l];
                v[i + j] = v1 + v2 * w;
                v[i + j + l] = v1 - v2 * w;
                w *= wd;
            }
        }
    }
}

int rnd() {
	return (rand() << 16) | rand();
}

int rnd(int l, int r) {
	return l + rnd() % (r - l + 1);
}

struct node {
	node *l, *r;
	int x, y;
	int cnt;

	node() {
		l = r = NULL;
		x = 0;
		y = rnd();
		cnt = 1;
	}
	node(int data) {
		l = r = NULL;
		x = data;
		y = rnd();
		cnt = 1;
	}
};

int sz(node *v) {
	return !v ? 0 : v->cnt;
}

node * rec(node *v) {
	if (!v)
		return v;
	v->cnt = sz(v->l) + sz(v->r) + 1;
	return v;
}

node *merge(node *l, node *r) {
	if (!l || !r)
		return !l ? r : l;
	if (l->y > r->y) {
		l->r = merge(l->r, r);
		return rec(l);
	}
	r->l = merge(l, r->l);
	return rec(r);
}

pair < node*, node* > split(node *v, int cnt) {
	if (!v)
		return{ NULL, NULL };
	if (sz(v->l) >= cnt) {
		auto p = split(v->l, cnt);
		v->l = p.second;
		return { p.first, rec(v) };
	}
	auto p = split(v->r, cnt - 1 - sz(v->l));
	v->r = p.first;
	return { rec(v), p.second };
}

void print(node *v) {
	if (!v)
		return;
	print(v->l);
	cout << v->x << ' ';
	print(v->r);
}

void println(node *v) {
#ifdef _DEBUG
	print(v);
	cout << endl;
#endif
}

void add(node *&root, int value) {
	root = merge(root, new node(value));
}

const int aholen = 1e2;
const int alp = 26;
int link[aholen][alp], go[aholen][alp], suf[aholen], suff[aholen], sym[aholen], ter[aholen], par[aholen];
int root = 0;
int tp = 0;

int create() {
	for (int i = 0; i < alp; i++)
		link[tp][i] = go[tp][i] = -1;
	suf[tp] = -1;
	suff[tp] = -1;
	sym[tp] = -1;
	ter[tp] = 0;
	return tp++;
}

void add(string &s) {
	int pos = root;
	for (int i = 0; i < s.size(); i++) {
		int sm = s[i] - 'a';
		if (link[pos][sm] == -1) {
			int f = create();
			link[pos][sm] = f;
			sym[f] = sm;
			par[f] = pos;
		}
		pos = link[pos][sm];
	}
	ter[pos]++;
}

int gsuf(int v);

int ggo(int v, int s) {
	if (go[v][s] != -1)
		return go[v][s];
	if (link[v][s] != -1)
		return go[v][s] = link[v][s];
	if (v == root)
		return go[v][s] = root;
	return go[v][s] = ggo(gsuf(v), s);
}

int gsuf(int v) {
	if (suf[v] != -1)
		return suf[v];
	if (v == root || par[v] == root)
		return suf[v] = root;
	return suf[v] = ggo(gsuf(par[v]), sym[v]);
}

int gsuff(int v) {
	if (suff[v] != -1)
		return suff[v];
	if (v == root || par[v] == root)
		return suff[v] = root;
	if (ter[gsuf(v)] != 0)
		return suff[v] = gsuf(v);
	return suff[v] = gsuff(gsuf(v));
}

const int len = 5e3;
vector < int > g[len];
bool used[len];

vector < int > buf;

bool dfs(int v, int d = 1) {
	bool can = false;
	if (d % 2 == 1)
		can = true;
	for (auto go : g[v]) {
		if (!used[go] && dfs(go, d + 1)) {
			can = true;
			break;
		}
	}
	if (can) {
		used[v] = true;
		buf.push_back(v);
	}
	return can;
}

int main() {
#ifdef _DEBUG
    freopen("input.txt", "r", stdin);
    freopen("output.txt", "w", stdout);
#endif
	string s;
	cin >> s;
	for (int i = 0; i < s.size(); i++) {
		if (s[i] == '0') {
			for (int j = i + 1; j < s.size(); j++)
				if (s[j] == '1')
					g[i].push_back(j);
		}
		else {
			for (int j = i + 1; j < s.size(); j++)
				if (s[j] == '0')
					g[i].push_back(j);
		}
	}
	vector < vector < int > > ans;
	for (int i = 0; i < s.size(); i++) {
		if (!used[i] && s[i] == '0') {
			buf.clear();
			dfs(i);
			ans.push_back(vector < int >());
			ans[ans.size() - 1] = buf;
		}
		if (s[i] == '1' && !used[i]) {
			cout << -1;
			return 0;
		}
	}
	cout << ans.size() << endl;
	for (auto line : ans) {
		reverse(line.begin(), line.end());
		cout << line.size() << ' ';
		for (auto el : line)
			cout << el + 1 << ' ';
		cout << endl;
	}
}