#include <map>
#include <set>
#include <list>
#include <ctime>
#include <deque>
#include <queue>
#include <stack>
#include <chrono>
#include <cstdio>
#include <random>
#include <vector>
#include <cassert>
#include <complex>
#include <cstdlib>
#include <iomanip>
#include <numeric>
#include <iostream>
#include <algorithm>
#include <functional>
#include <unordered_map>
#include <unordered_set>
#define int int64_t

using namespace std;
using namespace chrono;

class SegmentTree {
private:
	int n;
	vector<int64_t> tree;
	vector<int64_t> lazy;
	vector<char> isLazy;
	
	inline void push(int x, int tl, int tr) {
		if (!isLazy[x]) {
			return;
		}
		tree[x] = lazy[x] * (tr-tl+1);
		if (tl != tr) {
			lazy[x*2] = lazy[x];
			isLazy[x*2] = true;
			lazy[x*2+1] = lazy[x];
			isLazy[x*2+1] = true;
		}
		isLazy[x] = false;
	}
	
	inline void update(int x, int tl, int tr, int l, int r, int value) {
		push(x, tl, tr);
		if (l > r) {
			return;
		}
		if (l == tl && tr == r) {
			isLazy[x] = true;
			lazy[x] = value;
			push(x, tl, tr);
			return;
		}
		int tm = (tl + tr) / 2;
		update(x*2, tl, tm, l, min(r, tm), value);
		update(x*2+1, tm+1, tr, max(tm+1, l), r, value);
		tree[x] = tree[x*2] + tree[x*2+1];
	}
	
	inline int64_t sum(int x, int tl, int tr, int l, int r) {
		push(x, tl, tr);
		if (l > r) {
			return 0;
		}
		if (l == tl && tr == r) {
			return tree[x];
		}
		int tm = (tl + tr) / 2;
		return (
			sum(x*2, tl, tm, l, min(r, tm)) +
			sum(x*2+1, tm+1, tr, max(tm+1, l), r)
		);
	}
	
	inline int lBound(int x, int tl, int tr, int64_t need) {
		push(x, tl, tr);
		if (tl == tr) {
			return (tree[x] >= need) ? tl : tr+1;
		}
		int tm = (tl + tr) / 2;
		if (tree[x*2] >= need) {
			return lBound(x*2, tl, tm, need);
		} else {
			return lBound(x*2+1, tm+1, tr, need - tree[x*2]);
		}
	}
	
	inline int rBound(int x, int tl, int tr, int64_t need) {
		push(x, tl, tr);
		if (tl == tr) {
			return (tree[x] >= need) ? tl : tr-1;
		}
		int tm = (tl + tr) / 2;
		if (tree[x*2+1] >= need) {
			return rBound(x*2+1, tm+1, tr, need);
		} else {
			return rBound(x*2, tl, tm, need - tree[x*2+1]);
		}
	}
public:
	inline void update(int l, int r, int value) {
		update(1, 0, n-1, l, r, value);
	}
	
	inline int64_t sum(int l, int r) {
		return sum(1, 0, n-1, l, r);
	}
	
	inline int lBound(int64_t need) {
		return lBound(1, 0, n-1, need);
	}
	
	inline int rBound(int64_t need) {
		return rBound(1, 0, n-1, need);
	}
	
	SegmentTree(int n)
		: n(n), tree(4*n), lazy(4*n), isLazy(4*n, false) {
	}
};

inline int solve1(int n, int d, int b, const vector<int64_t> &v) {
	int64_t fsf = 0;
	
	int ans = 0;
	for (int i = 0; i < n; i++) {
		for (int64_t j = (int64_t)d*i; j < min((int64_t)n, (int64_t)d*(i+1)); j++) {
			fsf += v[j];
		}
		if (fsf >= b) {
			fsf -= b;
		} else {
			ans++;
		}
	}
	
	return ans;
}

inline int solve2(int n, int d, int b, const vector<int64_t> &v) {
	
	auto ok = [&](int val) {
		SegmentTree st(n);
		for (int i = 0; i < n; i++) {
			st.update(i, i, v[i]);
		}
		for (int i = val; i < (n+1) / 2; i++) {
			int64_t lb = min((int64_t)(i+1) * d, (int64_t)n) - 1;
			int64_t rb = n - lb - 1;
			// teacher 1
			do {
				int lNeed = st.lBound(b);
				if (lNeed > lb) {
					return false;
				}
				int64_t last = st.sum(0, lNeed) - b;
				st.update(0, lNeed-1, 0);
				st.update(lNeed, lNeed, last);
			} while (false);
			if (2*i+1 == n) {
				continue;
			}
			// teacher 2
			do {
				int rNeed = st.rBound(b);
				if (rNeed < rb) {
					return false;
				}
				int64_t last = st.sum(rNeed, n-1) - b;
				st.update(rNeed+1, n-1, 0);
				st.update(rNeed, rNeed, last);
			} while (false);
		}
		return true;
	};
	
	int l = 0, r = (n+42) / 2;
	while (l != r) {
		int m = (l + r) / 2;
		if (ok(m)) {
			r = m;
		} else {
			l = m+1;
		}
	}
	
	return l;
}

signed main() {
	
	int nn = 100 * 1000;
	vector<int64_t> vv(nn);
	for (int i = 0; i < nn; i++) {
		vv[i] = 42;
	}
	cout << solve2(nn, 1, 42, vv) << endl;
	return 0;
	
	#ifdef DEBUG
		stdin = freopen("input.txt", "r", stdin);
	#endif
	ios_base::sync_with_stdio(false);
	
	int p, n, d, b; cin >> p >> n >> d >> b;
	vector<int64_t> v(n);
	for (int i = 0; i < n; i++) {
		cin >> v[i];
	}
	
	if (p == 1) {
		cout << solve1(n, d+1, b, v) << endl;
	} else {
		cout << solve2(n, d+1, b, v) << endl;
	}
	
	return 0;
}
