#include<iostream>
#include <vector>
#include <numeric>
#include <algorithm>

using namespace std;

typedef long long ll;

template <typename T>
istream &operator>>(istream &in, vector<T> &a) {
    for (auto &x : a) {
        in >> x;
    }
    return in;
}

template<typename T>
ostream &operator<<(ostream &out, vector<T> &a) {
    for (auto &x : a) {
        out << x << " ";
    }
    return out;
}

template<typename T>
ostream &operator<<(ostream &out, vector<vector<T>> &a) {
    for (auto &x : a) {
        out << x << "\n";
    }
    return out;
}

struct DSU {
    int n;
    vector<int> pr, sz;

    int getPr(int v) {
        return (pr[v] == v ? v : pr[v] = getPr(pr[v]));
    }

    void join(int u, int v) {
        u = getPr(u);
        v = getPr(v);
        if (u == v) return;
        if (sz[u] < sz[v]) swap(u, v);
        sz[u] += sz[v];
        pr[v] = u;
    }

    DSU(int n): n(n), pr(n), sz(n, 1) {
        iota(pr.begin(), pr.end(), 0);
    }
};

const int INF = (int) 1e9;

struct Graph {
    int n;
    vector<vector<int>> g;
    vector<vector<int>> rg;
    vector<bool> used;
    DSU dsu;

    void add(int v, int u) {
        g[v].push_back(u);
        rg[u].push_back(v);
    }

    vector<int> ord;

    void topSort(int v) {
        used[v] = true;
        for (auto to : g[v]) {
            if (!used[to]) {
                topSort(to);
            }
        }
        ord.push_back(v);
    }

    vector<int> comp;

    void dfs(int v) {
        used[v] = true;
        comp.push_back(v);
        for (auto to : rg[v]) {
            if (!used[to]) {
                dfs(to);
            }
        }
    }

    vector<int> comps;
    vector<int> ind;

    void get() {
        used.assign(n, false);
        for (int i = 0; i < n; ++i) {
            if (!used[i]) {
                topSort(i);
            }
        }
        reverse(ord.begin(), ord.end());
        used.assign(n, false);
        for (auto v : ord) {
            if (!used[v]) {
                comp.clear();
                dfs(v);
                for (int i = 1; i < comp.size(); ++i) {
                    dsu.join(comp[i], comp[i - 1]);
                }
                ind[dsu.getPr(comp[0])] = comps.size();
                comps.push_back(dsu.sz[dsu.getPr(comp[0])]);
            }
        }
        for (int v = 0; v < n; ++v) {
            for (auto to : g[v]) {
                if (dsu.getPr(to) != dsu.getPr(v)) {
                    comps[ind[dsu.getPr(v)]] = INF;
                }
            }
        }
        int ans = INF;
        int index = -1;
        for (int i = 0; i < comps.size(); ++i) {
            if (ans > comps[i]) {
                ans = comps[i];
                index = i;
            }
        }
        cout << ans << "\n";
        for (int v = 0; v < n; ++v) {
            if (ind[dsu.getPr(v)] == index) {
                cout << v + 1 << " ";
            }
        }
        cout << "\n";
    }

    Graph(int n): n(n), g(n), rg(n), used(n, false), dsu(n), ind(n) { }
};

int main() {
    int n, m, h;
    cin >> n >> m >> h;
    vector<int> w(n);
    cin >> w;
    Graph g(n);
    for (int i = 0; i < m; ++i) {
        int f, t;
        cin >> f >> t;
        --f, --t;
        if ((w[f] + 1) % h == w[t]) {
            g.add(f, t);
        }
        if ((w[t] + 1) % h == w[f]) {
            g.add(t, f);
        }
    }
    g.get();
    return 0;
}
/*
3 3 5
4 4 0
1 3
3 2
3 1

4 5 4
2 1 0 3
4 3
3 2
1 2
1 4
1 3
*/