#include <bits/stdc++.h>

using namespace std;

typedef long long ll;
typedef unsigned long long ull;
typedef long double ld;
typedef unsigned int uint;

mt19937 my_random;

struct Node {
    int val;
    int sum;
    int prior;
    int promise;
    int size;
    Node *left, *right;

    Node(int _val) : val(_val), prior(my_random()), promise(-1), size(1), sum(_val), left(nullptr), right(nullptr) {}
};

Node *root;

int size(Node *v) {
    return v ? v->size : 0;
}

void push(Node *v) {
    if (!v || v->promise == -1)
        return;
    if (v->left)
        v->left->promise = v->promise;
    if (v->right)
        v->right->promise = v->promise;
    v->val = size(v) * v->promise;
    v->promise = -1;
}

void recalc(Node *v) {
    v->sum = v->val;
    if (v->left)
        v->sum += v->left->sum;
    if (v->right)
        v->sum += v->right->sum;
    v->size = size(v->left) + size(v->right) + 1;
}

pair<Node *, Node *> split(Node *v, int k) {
    if (!v)
        return {nullptr, nullptr};
    push(v);
    if (k <= size(v->left)) {
        auto tmp = split(v->left, k);
        v->left = tmp.second;
        recalc(v);
        return {tmp.first, v};
    } else {
        auto tmp = split(v->right, k - size(v->left) - 1);
        v->right = tmp.first;
        recalc(v);
        return {v, tmp.second};
    }
};

Node *merge(Node *l, Node *r) {
    if (!l)
        return r;
    if (!r)
        return l;
    push(l);
    push(r);
    if (l->prior > r->prior) {
        l->right = merge(l->right, r);
        recalc(l);
        return l;
    } else {
        r->left = merge(l, r->left);
        recalc(r);
        return r;
    }
}

void assign(int ql, int qr, int val) {
    if (ql > qr) return;
    auto tmp1 = split(root, qr);
    auto tmp2 = split(tmp1.first, ql - 1);
    tmp2.second->promise = val;
    root = merge(merge(tmp2.first, tmp2.second), tmp1.second);
}

void rotate(int ql, int qr, int d) {
    if (ql > qr) return;
    d %= qr - ql + 1;
    auto tmp1 = split(root, qr);
    auto tmp2 = split(tmp1.first, ql - 1);
    auto tmp3 = split(tmp2.second, d);
    root = merge(merge(tmp2.first, merge(tmp3.second, tmp3.first)), tmp1.second);
}

int get_sum(int ql, int qr) {
    if (ql > qr) return 0;
    auto tmp1 = split(root, qr);
    auto tmp2 = split(tmp1.first, ql - 1);
    int ans = tmp2.second->sum;
    root = merge(merge(tmp2.first, tmp2.second), tmp1.second);
    return ans;
}

void push_back(int val) {
    root = merge(root, new Node(val));
}

int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);
    cout.tie(nullptr);
    cerr.tie(nullptr);

    int p, n, d, b;
    cin >> p >> n >> d >> b;

    for (int i = 0; i < n; i++) {
        int t;
        cin >> t;
        push_back(t);
    }

    int err = 0;
    for (int i = 1; i < n; i++) {
        int all = get_sum(i + 1, i + d), here = get_sum(i, i);
        assign(i + 1, i + d, 0);
        int t;
        if (here + all >= b) {
            assign(i, i, b);
            assign(i + 1, i + 1, 0);
            t = all + here - b;
        } else {
            t = here + all;
            err++;
        }
        rotate(i + 1, n, d);
        assign(i + 1, i + 1, get_sum(i + 1, i + 1) + t);
    }

    cout << err;

    return 0;
}