#include <iostream>
#include <vector>
#include <algorithm>


using namespace std;


#define v_left(v) 2 * v + 1
#define v_right(v) 2 * v + 2
#define parent(v) (v - 1) / 2

template<typename T>
class LST {
private:
    vector<T> data;
    int head_size;

    void update(int v) {
        data[v] = data[v_left(v)] + data[v_right(v)];
    }

public:
    template<typename It>
    LST(It begin, It end) {
        int n = end - begin;

        int m = 1;
        for (; m < n; m <<= 1);

        head_size = m - 1;

        data.resize(head_size + m, 0);

        for (int i = 0; i < n; ++i) {
            data[head_size + i] = *begin++;
        }

        for (int i = head_size - 1; i >= 0; --i) {
            update(i);
        }
    }

    int get(int L, int R) {
        L += head_size;
        R += head_size - 1;

        T left_res = 0, right_res = 0;

        while (L < R) {
            if (L % 2) {
                left_res += data[L++];
            }

            L = parent(L);

            if (R % 2 == 0) {
                right_res += data[R--];
            }

            R = parent(R);
        }

        if (L == R) {
            left_res += data[L];
        }

        return left_res + right_res;
    }

    void set(int i, T value) {
        i += head_size;

        data[i] = value;

        while (i) {
            update(i /= 2);
        }
    }
};

#undef v_left
#undef v_right
#undef parent


int main() {
	int p, n, d, b;
	cin >> p >> n >> d >> b;

	vector<int> rooms(n);
	for (int i = 0; i < n; ++i) {
		cin >> rooms[i];
		rooms[i] -= b;
	}

	if (p == 1) {
		int to_build = n - 1, to_take = n - 1;

		while (to_build >= 0 && to_take >= 0) {
			while (to_build >= 0 && rooms[to_build] >= 0) {
				--to_build;
			}

			while (to_take >= 0 && rooms[to_take] < 0) {
				--to_take;
			}

			if (to_take < 0) {
				cout << to_build + 1;

				return 0;
			}

			if (to_build < 0) {
				cout << 0;

				return 0;
			}

			if (to_take > to_build) {
				if (rooms[to_take] == 0) {
					--to_take;
					continue;
				}

				if (to_take - to_build <= (to_build + 1) * d) {
					if (rooms[to_take] < -rooms[to_build]) {
						rooms[to_build] += rooms[to_take];
						rooms[to_take] = 0;
						--to_take;
					} else {
						rooms[to_take] += rooms[to_build];
						rooms[to_build] = 0;
						--to_build;
					}
				} else {
					--to_take;
				}
			} else {
				rooms[to_take] += rooms[to_build];
				rooms[to_build] = 0;
				--to_build;
			}
		}

		if (to_take < 0) {
			cout << to_build + 1;

			return 0;
		}

		if (to_build < 0) {
			cout << 0;

			return 0;
		}
	}

    return 0;
}