#include <iostream>
#include <vector>
#include <map>
#include <set>
#include <ctime>
#include <string>
#include <cmath>
#include <algorithm>
typedef long long ll;
#define FOR(i, n) for (ll i = 0; i < n; ++i)
#define debug(x) std::cerr << #x << ": " << (x) << '\n'

struct fenwick {
	std::vector<ll> f;

	fenwick(ll n) {
		f.resize(n);
	}

	ll get(ll ind) {
		ll sum = 0;
		for (ll i = ind; i >= 0; i = (i & (i + 1)) - 1) {
			sum += f[i];
		}
		return sum;
	}

	void add(ll ind, ll value) {
		if (ind < 0) {
			return;
		}
		for (ll i = ind; i < f.size(); i = (i | (i + 1))) {
			f[i] += value;
		}
	}

	ll get(ll l, ll r) {
		r = std::min(r, (ll)f.size() - 1LL);
		return get(r) - get(l - 1);
	}
};

int main() {
	std::ios::sync_with_stdio(false);
	std::cin.tie(0);
	std::srand(std::time(NULL));
	int p, n, d, b;
	std::cin >> p >> n >> d >> b;
	ll answ = 0;
	std::vector<ll>a(n);
	fenwick pref(n);
	FOR(i, n) {
		std::cin >> a[i];
		pref.add(i, a[i]);
	}
	if (p == 1) {
		FOR(i, n) {
			ll need = b - pref.get(i, i);
			if (need <= 0) {
				pref.add(i, need);
				pref.add(i + 1, -need);
				continue;
			}
			if (pref.get(i + 1, i + (i + 1) * d) >= need) {
				pref.add(i, need);
				pref.add(i + 1, -need);
			} else {
				pref.add(i + 1, pref.get(i, i));
				answ++;
			}
		}
	}
	if (p == 2) {
		FOR(i, n) {
			ll pref_now = i;
			std::vector<ll> new_a = a;
			int l = 0, r = n - 1;
			int L = i, R = n - i - 1;
			int move = i;
			while (L <= R && r > l) {
				while (new_a[l] > 0 && abs(l - L) <= (move + 1) * d) {
					new_a[l]--;
					++L;
					move = std::min(L, n - R - 1);
				}
				while (new_a[r] > 0 && abs(r - R) <= (move + 1) * d) {
					new_a[r]--;
					--R;
					move = std::min(L, n - R - 1);
				}
				if (new_a[l] == 0) {
					++l;
				}
				if (new_a[r] == 0) {
					--r;
				}
			}
			if (L > R) {
				std::cout << i;
				return 0;
			}
		}
	}
	std::cout << answ;
}